@@ -20,10 +20,10 @@ def append_to_path(d):
     
 def update_path_for_stempy():
     d = os.path.dirname(__file__)
-    append_to_path(os.path.normpath(os.path.join(d, '..'))) # stempy
-    append_to_path(os.path.normpath(os.path.join(d, '..', '..', '..', 'Python', 'Cookbook'))) # cookbook
-    append_to_path(os.path.normpath(os.path.join(d, '..', '..', '..', 'Infpy', 'python'))) # Infpy
-    append_to_path(os.path.normpath(os.path.join(d, '..', '..', '..', 'PyICL', 'Python'))) # PyICL
+    append_to_path(os.path.normpath(os.path.join(d, '..', '..'))) # stempy
+    append_to_path(os.path.normpath(os.path.join(d, '..', '..', '..', '..', 'Python', 'Cookbook'))) # cookbook
+    append_to_path(os.path.normpath(os.path.join(d, '..', '..', '..', '..', 'Infpy', 'python'))) # Infpy
+    append_to_path(os.path.normpath(os.path.join(d, '..', '..', '..', '..', 'PyICL', 'Python'))) # PyICL
 
 def fasta_dir():
     return os.path.normpath(os.path.join(os.path.dirname(__file__), 'fasta'))
